@@ -3,6 +3,5 @@ setGeneric( "isInitialized", function( object, ... ){
 	standardGeneric( "isInitialized" )
 } )
 setMethod( "isInitialized", "Message", function(object, ... ){
-	.Call( "is_message_initialized", object@pointer, PACKAGE = "RProtoBuf" )
+	.Call( Message__is_initialized, object@pointer )
 } )
-
